{
  description = "NixOS configuration flake";

  inputs = {
    nixpkgs.url = "github:NixOS/nixpkgs/nixos-24.05";
    home-manager.url = "github:nix-community/home-manager/release-24.05";
    home-manager.inputs.nixpkgs.follows = "nixpkgs";
  };

  outputs = { self, nixpkgs, home-manager, ...}:
    let
      system = "x86_64-linux";
      pkgs = nixpkgs.legacyPackages.${system};
    in {
      nixosConfigurations = {
        lift = nixpkgs.lib.nixosSystem {
          inherit system;
          modules = [
            ./configuration.nix
            ./sway.nix
            ./hardware-configuration.nix
          ];
        };
      };
      homeConfigurations = {
        "rothe@lift" = home-manager.lib.homeManagerConfiguration {
          inherit pkgs;
          modules = [ 
            ./home/rothe.nix
            ./home/wayland
          ];
          extraSpecialArgs = {
            mail = "mail@johannes-rothe.de";
          };
        };
        "rothe@johannes-powermachine" = home-manager.lib.homeManagerConfiguration {
          inherit pkgs;
          modules = [ 
            ./home/rothe.nix
          ];
          extraSpecialArgs = {
            mail = "mail@johannes-rothe.de";
          };
        };
        "rothe@pdemu1cml000301" = home-manager.lib.homeManagerConfiguration {
          inherit pkgs;
          modules = [ 
            ./home/rothe.nix
          ];
          extraSpecialArgs = {
            mail = "rothe@magazino.eu";
          };
        };
      };
    };
}
